/*
 * Copyright (C) 2001-2006 The Mir-coders group
 *
 * This file is part of Mir.
 *
 * Mir is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Mir is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Mir; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * In addition, as a special exception, The Mir-coders gives permission to link
 * the code of this program with  any library licensed under the Apache Software License,
 * and distribute linked combinations including the two.  You must obey the
 * GNU General Public License in all respects for all of the code used other than
 * the above mentioned libraries.  If you modify this file, you may extend this
 * exception to your version of the file, but you are not obligated to do so.
 * If you do not wish to do so, delete this exception statement from your version.
 */
package mir.producer;

import mir.util.ParameterExpander;
import mir.util.RewindableIterator;

import java.util.Collection;
import java.util.Iterator;

public class ListEnumeratingProducerNode extends ProducerNodeDecorator {
  private String key;
  private String listExpression;

  public ListEnumeratingProducerNode( String aKey, String aListExpression, ProducerNode aSubNode) {
    super(aSubNode);

    key = aKey;
    listExpression = aListExpression;
  }

  public void produce(ProductionContext aProductionContext) throws ProducerFailure, ProducerExc {
    Iterator browser;
    Object list;

    try {
      list = ParameterExpander.evaluateExpression(aProductionContext.getValueSet(), listExpression);
      if (list != null) {
        if (list instanceof Collection) {
          browser = ( (Collection) list).iterator();
        }
        else if (list instanceof Iterator) {
          browser = (Iterator) list;
        }
        else {
          throw new ProducerExc("Can't enumarate a " + list.getClass().getName());
        }

        if (browser instanceof RewindableIterator) {
          ((RewindableIterator) browser).rewind();
        }

        while (browser.hasNext() && !isAborted(aProductionContext)) {
          ParameterExpander.setValueForKey(aProductionContext.getValueSet(), key, browser.next());

          super.produce(aProductionContext);
        }
      }
    }
    catch (Throwable t) {
      aProductionContext.getLogger().warn("Exception occurred inside an ListEnumeratingProducerNode", t);
    }
  }
}
